"""
Django settings for core project.

Generated by 'django-admin startproject' using Django 1.10.

For more information on this file, see
https://docs.djangoproject.com/en/1.10/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.10/ref/settings/
"""

# Imports from python
import os


# Imports from other dependencies.
import dj_database_url


# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
PROJECT_DIR = os.path.dirname(os.path.abspath(__file__))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.10/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ['DJANGO_SECRET_KEY']

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = os.getenv('DEBUG_MODE', 'off') == 'on'

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    # packages
    # 'djangoformsetjs',
    # 'debug_toolbar',

    # apps
    'datafreezer',
    'dynamic_formsets',
]

MIDDLEWARE = [
    # default
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',

    # packages
    # 'debug_toolbar.middleware.DebugToolbarMiddleware'
]

ROOT_URLCONF = 'core.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                # for using {{ MEDIA_URL }}
            ],
        },
    },
]

WSGI_APPLICATION = 'core.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.10/ref/settings/#databases

DATABASES = {
    'default': dj_database_url.config(default=os.environ['DATABASE_URL']),
}


# Password validation
# https://docs.djangoproject.com/en/1.10/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': '.'.join([
            'django.contrib.auth.password_validation',
            'UserAttributeSimilarityValidator',
        ]),
    },
    {
        'NAME': '.'.join([
            'django.contrib.auth.password_validation',
            'MinimumLengthValidator',
        ]),
    },
    {
        'NAME': '.'.join([
            'django.contrib.auth.password_validation',
            'CommonPasswordValidator',
        ]),
    },
    {
        'NAME': '.'.join([
            'django.contrib.auth.password_validation',
            'NumericPasswordValidator',
        ]),
    },
]


# Internationalization
# https://docs.djangoproject.com/en/1.10/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'America/Chicago'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.10/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(PROJECT_DIR, 'static')


# Uploaded files

MEDIA_ROOT = os.path.join(BASE_DIR, 'datafreezer/uploads/')
MEDIA_URL = '/media/'

# Django Debug Toolbar
# https://django-debug-toolbar.readthedocs.io/en/stable/installation.html

# DEBUG_TOOLBAR_PATCH_SETTINGS = False
# INTERNAL_IPS = [
#     '127.0.0.1',
#     '::1'
#     ]

# Datafreezer Settings

HUBS_LIST_URL = 'http://datalab.dallasnews.com/staff/api/hub/'
STAFF_LIST_URL = 'http://datalab.dallasnews.com/staff/api/staff/'
